@@ -67,7 +67,7 @@ def load_rc(ofile: str) -> List[str] | None:
     try:
         with open(ofile) as fd:
             rc = reduce(_split_file, fd, [])
-    except EnvironmentError as exc:
+    except OSError as exc:
         ud.debug(ud.LISTENER, ud.ERROR, 'Failed to open "%s": %s' % (ofile, exc))
     return rc
 
