@@ -7,10 +7,10 @@
 ##   - univention-directory-manager-tools
 ## packages-not:
 ##   - univention-ad-connector
-## bugs:
-##   - 56999
 
 
+import base64
+import os
 import time
 
 import pytest
@@ -20,6 +20,11 @@ from univention.admin.uldap import getAdminConnection
 from univention.testing.utils import package_installed
 
 
+CWD = os.path.dirname(os.path.abspath(__file__))
+jpeg_bytes = open(f'{CWD}/example_user_jpeg_photo.jpg', 'rb').read()
+b64encoded_jpeg_photo = base64.b64encode(jpeg_bytes).decode('ascii')
+
+
 def create_user(new, username, maildom):
     new['title'] = f'{username}-title'
     new['firstname'] = f'{username}-firstname'
@@ -27,7 +32,7 @@ def create_user(new, username, maildom):
     new['username'] = username
     new['description'] = f'{username}-description'
     new['mailPrimaryAddress'] = f'{username}@{maildom}'
-    new['jpegPhoto'] = '/9j/4AAQSkZJRgABAQEASABIAAD/2wBDAP//////////////////////////////////////////////////////////////////////////////////////wgALCAABAAEBAREA/8QAFBABAAAAAAAAAAAAAAAAAAAAAP/aAAgBAQABPxA='
+    new['jpegPhoto'] = b64encoded_jpeg_photo
     new['organisation'] = f'{username}-organisation'
     new['employeeNumber'] = f'{username}-employeeNumber'
     new['employeeType'] = f'{username}-employeeType'
@@ -100,7 +105,8 @@ def mail_domain_name(udm, random_name):
     return mail_domain_name
 
 
-def test_create_1000_users_with_extreme_blocklist_setup(blocklist_setup, mail_domain_name):
+@pytest.mark.usefixtures('blocklist_setup')
+def test_create_1000_users_with_extreme_blocklist_setup(mail_domain_name):
     number_of_users = 1000
     lo, position = getAdminConnection()
     modules.update()
@@ -108,7 +114,7 @@ def test_create_1000_users_with_extreme_blocklist_setup(blocklist_setup, mail_do
     modules.init(lo, position, users)
     configRegistry['directory/manager/user/primarygroup/update'] = 'false'
     configRegistry['directory/manager/blocklist/enabled'] = 'true'
-    start = time.monotonic()
+    start = time.time()
     user_dns = []
     try:
         for i in range(number_of_users):
@@ -116,11 +122,11 @@ def test_create_1000_users_with_extreme_blocklist_setup(blocklist_setup, mail_do
             new = users.object(None, lo, position)
             user_dns.append(create_user(new, username, mail_domain_name))
     finally:
-        end = time.monotonic()
+        end = time.time()
         for dn in user_dns:
             lo.delete(dn)
     duration = end - start
     if package_installed('univention-samba4'):
-        assert duration < 3000  # FXIME: hard coded performance timeout sucks
+        assert duration < 300
     else:
-        assert duration < 2500  # FXIME: hard coded performance timeout sucks
+        assert duration < 250
