@@ -53,7 +53,7 @@ def get_code_position(depth=1, line_length=80, fill_char='.', prefix="# ", color
         return color_start + ("%80s" % '').replace(' ', '=') + color_stop
 
 
-def hook_setup(app_name):
+def setup(app_name):
     """
     the setup creates the necessary script hook folders and places a script in
     each of them with the filename being the action name. The script will
@@ -120,7 +120,7 @@ def app_install(appcenter, app_name):
     appcenter.update()
 
     app.install()  # install the app
-    app.verify(joined=False)
+    app.verify()
     return app
 
 
@@ -134,7 +134,7 @@ def app_upgrade(appcenter, app_name):
     appcenter.update()
 
     app.upgrade()  # now upgrade the app
-    app.verify(joined=False)
+    app.verify()
     return app
 
 
@@ -168,7 +168,7 @@ def test_app_install_update_remove_hooks(appcenter, app_name):
     these actions should then execute its hook scripts and if that works a
     resulting log file contains their script file names.
     """
-    hook_setup(app_name)
+    setup(app_name)
 
     app = app_install(appcenter, app_name)
     app = app_upgrade(appcenter, app_name)
