@@ -70,7 +70,7 @@ def test_docker_compose(appcenter):
         app.add_to_local_appcenter()
         appcenter.update()
         app.install()
-        app.verify(joined=False)
+        app.verify()
         images = subprocess.check_output(['docker', 'images'], text=True)
         assert alpine_checksum in images, images
         app.execute_command_in_container(f'touch /var/lib/univention-appcenter/apps/{name}/data/test1.txt')
@@ -85,7 +85,7 @@ def test_docker_compose(appcenter):
         app.add_to_local_appcenter()
         appcenter.update()
         app.upgrade()
-        app.verify(joined=False)
+        app.verify()
         images = subprocess.check_output(['docker', 'images'], text=True)
         assert alpine_checksum not in images, images
         app.execute_command_in_container(f'ls /var/lib/univention-appcenter/apps/{name}/data/test1.txt')
