@@ -139,17 +139,6 @@ def tiny_app_apache(name=None, version=None):
     return app
 
 
-def get_docker_appbox_ucs():
-    # should be in line with get_docker_appbox_image()
-    return '4.4'
-
-
-def get_docker_appbox_image():
-    image_name = f'docker-test.software-univention.de/ucs-appbox-amd64:{get_docker_appbox_ucs()}-8'
-    print('Using %s' % image_name)
-    return image_name
-
-
 def docker_login(server='docker.software-univention.de'):
     cmd = ['docker', 'login', '-u', 'ucs', '-p', 'readonly', server]
     error_handling_call(cmd, exc=UCSTest_Docker_LoginFailed)
@@ -380,13 +369,10 @@ class App:
         self.reload_container_id()
         self.installed = True
 
-    def verify(self, joined=True):
-        print('App.verify(%r)' % (joined,))
+    def verify(self):
+        print('App.verify()')
         error_handling_call(['univention-app', 'status', '%s=%s' % (self.app_name, self.app_version)], exc=UCSTest_DockerApp_VerifyFailed)
 
-        if joined:
-            error_handling_call(['docker', 'exec', self.container_id, 'univention-check-join-status'], exc=UCSTest_DockerApp_VerifyFailed)
-
         if self.package:
             try:
                 output = subprocess.check_output(['univention-app', 'shell', '%s=%s' % (self.app_name, self.app_version), 'dpkg-query', '-W', self.package_name], text=True)
@@ -464,14 +450,11 @@ class App:
         self.execute_command_in_container('/bin/sh -c "echo TEST-%s > /web/html/%s/index.txt"' % (self.app_name, self.app_name))
 
     def verify_basic_modproxy_settings_tinyapp(self, http=True, https=True):
-        return self.verify_basic_modproxy_settings(http=http, https=https, verify=False)
-
-    def verify_basic_modproxy_settings(self, http=True, https=True, verify='/etc/univention/ssl/ucsCA/CAcert.pem'):
         fqdn = '%(hostname)s.%(domainname)s' % self.ucr
         test_string = 'TEST-%s\n' % self.app_name
         protocols = {'http': http, 'https': https}
         for protocol, should_succeed in protocols.items():
-            response = requests.get(f'{protocol}://{fqdn}/{self.app_name}/index.txt', verify=verify)
+            response = requests.get(f'{protocol}://{fqdn}/{self.app_name}/index.txt', verify=False)  # noqa: S501
             try:
                 response.raise_for_status()
             except requests.exceptions.HTTPError:
@@ -506,13 +489,11 @@ class Appcenter:
             raise AppcenterRepositoryAlreadyExists()
 
         if not version:
-            self.add_ucs_version_to_appcenter('4.1')
-            self.add_ucs_version_to_appcenter('4.2')
-            self.add_ucs_version_to_appcenter('4.3')
             self.add_ucs_version_to_appcenter('4.4')
             self.add_ucs_version_to_appcenter('5.0')
-            self.versions = ['4.1', '4.2', '4.3', '4.4', '5.0']
-            self._write_ucs_ini('[5.0]\nSupportedUCSVersions=5.0, 4.4, 4.3\n[4.4]\nSupportedUCSVersions=4.4, 4.3, 4.2, 4.1\n[4.3]\nSupportedUCSVersions=4.3, 4.2, 4.1\n')
+            self.add_ucs_version_to_appcenter('5.1')
+            self.versions = ['4.4', '5.0', '5.1']
+            self._write_ucs_ini('[5.1]\nSupportedUCSVersions=5.1, 5.0, 4.4\n[5.0]\nSupportedUCSVersions=5.0, 4.4, 4.3\n[4.4]\nSupportedUCSVersions=4.4, 4.3, 4.2, 4.1\n[4.3]\nSupportedUCSVersions=4.3, 4.2, 4.1\n')
             self._write_suggestions_json()
         else:
             self.add_ucs_version_to_appcenter(version)
