@@ -5,22 +5,17 @@
 ## exposure: dangerous
 
 import os
-import shutil
 import socket
 
 import dns.resolver
 import pytest
 import requests
-from utils import (
-    get_portal_tile, grant_oidc_privileges, host_is_alive, keycloak_get_request, keycloak_post_request,
-    keycloak_sessions_by_user, run_command,
-)
+from utils import get_portal_tile, host_is_alive, keycloak_get_request, keycloak_sessions_by_user, run_command
 
 from univention.testing.utils import get_ldap_connection
 
 
-@pytest.mark.parametrize('protocol', ['saml', 'oidc'])
-def test_session_sync(ucr, udm, portal_login_via_keycloak, portal_config, keycloak_config, protocol):
+def test_session_sync(ucr, udm, portal_login_via_keycloak, portal_config, keycloak_config):
     """
     Test session sync between two keycloak servers.
     Configure system so that keycloak fqdn points to system one
@@ -50,7 +45,7 @@ def test_session_sync(ucr, udm, portal_login_via_keycloak, portal_config, keyclo
     # login on login_host
     username = udm.create_user()[1]
     print(f'login to {login_url} ({login_ip})')
-    page = portal_login_via_keycloak(username, 'univention', url=login_url, protocol=protocol)
+    page = portal_login_via_keycloak(username, 'univention', url=login_url)
     # change ucs-sso-ng to check_ip
     ucr.handler_unset([f'hosts/static/{login_ip}'])
     ucr.handler_set([f'hosts/static/{check_ip}={fqdn}'])
@@ -59,17 +54,14 @@ def test_session_sync(ucr, udm, portal_login_via_keycloak, portal_config, keyclo
     # check portal in check_url
     print(f'check session on {check_url} ({check_ip})')
     page.goto(check_url)
-    login_tile = portal_config.sso_oidc_login_tile if protocol == 'oidc' else portal_config.sso_login_tile
-    get_portal_tile(page, login_tile, portal_config).click()
-    grant_oidc_privileges(page)
+    get_portal_tile(page, 'Login (Single sign-on)', portal_config).click()
     page.click(f"[id='{portal_config.header_menu_id}']")
     a = page.locator(f'.{portal_config.portal_sidenavigation_username_class}').first
     assert a.inner_html() == username
     # check sessions
     sessions = keycloak_sessions_by_user(keycloak_config, username)[0]
-    sso_protocol = 'oidc/' if protocol == 'oidc' else 'saml/metadata'
-    assert f'{login_url}/univention/{sso_protocol}' in sessions['clients'].values()
-    assert f'{check_url}/univention/{sso_protocol}' in sessions['clients'].values()
+    assert f'{login_url}/univention/saml/metadata' in sessions['clients'].values()
+    assert f'{check_url}/univention/saml/metadata' in sessions['clients'].values()
 
 
 def test_every_umc_server_has_a_saml_client(ucr, keycloak_config):
@@ -85,46 +77,13 @@ def test_every_umc_server_has_a_saml_client(ucr, keycloak_config):
         assert f'https://{host}/univention/saml/metadata' in kc_clients
 
 
-def test_every_umc_server_has_a_oidc_client(ucr, keycloak_config):
+def test_list_users_works(keycloak_config):
+    """See https://forge.univention.org/bugzilla/show_bug.cgi?id=57205"""
+    # check that there is an object with objectclass=person but without uid
     ldap = get_ldap_connection()
-    umc_hosts = ldap.search('univentionService=Univention Management Console', attr=['cn'])
-    umc_hosts = [f"{host[1]['cn'][0].decode('utf-8')}.{ucr['domainname']}" for host in umc_hosts]
-    umc_hosts = [host for host in umc_hosts if host_is_alive(host)]
-    kc_clients = [client['clientId'] for client in keycloak_get_request(keycloak_config, 'realms/ucs/clients')]
-    for host in umc_hosts:
-        assert f'https://{host}/univention/oidc/' in kc_clients
-
-
-@pytest.mark.parametrize('realm', ['master', 'ucs'])
-def test_rest_api_endpoints(keycloak_config, realm: str):
-    """
-    Test some of the REST endpoints
-
-    In the past we made changes that broke the user list request,
-    test some of the endpoints here to make sure they work
-
-    See https://forge.univention.org/bugzilla/show_bug.cgi?id=57205
-    """
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/users/profile')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/users')
-    users = keycloak_get_request(keycloak_config, f'realms/{realm}/ui-ext/brute-force-user')
-    assert users
-    some_user_id = users[0]['id']
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/users/{some_user_id}?userProfileMetadata=true')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/clients')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/client-scopes')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/roles')
-    keycloak_get_request(keycloak_config, f'realms/{realm}/groups')
-    keycloak_post_request(keycloak_config, f'realms/{realm}/logout-all')
-    keycloak_get_request(keycloak_config, f'realms/{realm}/ui-ext/sessions')
-    keycloak_get_request(keycloak_config, f'realms/{realm}/admin-events')
-    keycloak_get_request(keycloak_config, f'realms/{realm}/events')
-    keycloak_get_request(keycloak_config, f'realms/{realm}/authentication/unregistered-required-actions')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/authentication/required-actions')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/authentication/flows')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/ui-ext/authentication-management/flows')
-    assert keycloak_get_request(keycloak_config, f'realms/{realm}/components')
+    assert ldap.search('(&(objectclass=person)(!(uid=*)))')
+    assert keycloak_get_request(keycloak_config, 'realms/master/users')
+    assert keycloak_get_request(keycloak_config, 'realms/ucs/users')
 
 
 def test_master_realm_config(keycloak_config, ucr):
@@ -142,7 +101,6 @@ def test_master_realm_config(keycloak_config, ucr):
     components = keycloak_get_request(keycloak_config, f"realms/master/components?parent={ldap_federation['id']}")
     components = [c['name'] for c in components]
     assert set(components) == {
-        'Kerberos principal attribute mapper',
         'admin-role',
         'last name',
         'modify date',
@@ -179,7 +137,6 @@ def test_ucs_realm_config(keycloak_config, ucr):
     components = keycloak_get_request(keycloak_config, f"realms/ucs/components?parent={ldap_federation['id']}")
     components = [c['name'] for c in components]
     assert set(components) == {
-        'Kerberos principal attribute mapper',
         'uid',
         'creation date',
         'username',
@@ -209,18 +166,6 @@ def test_csp(keycloak_config, ucr):
         run_command(['systemctl', 'restart', 'apache2'])
         response = requests.post(f'{keycloak_config.admin_url}/master/console', headers={'Accept': 'text/html'})
         assert response.headers['Content-Security-Policy']
-        assert f"frame-src 'self'; frame-ancestors 'self' https://*.{ucr['domainname']} https://login.microsoftonline.com https://*.external.com;  object-src 'none';" == response.headers['Content-Security-Policy']
+        assert f"frame-src 'self'; frame-ancestors 'self' https://*.{ucr['domainname']} https://*.external.com;  object-src 'none';" == response.headers['Content-Security-Policy']
     finally:
         run_command(['systemctl', 'restart', 'apache2'])
-
-
-@pytest.mark.roles('domaincontroller_master')
-def test_additional_ca_certifiates_issue_223():
-    ca_dir = '/var/lib/univention-appcenter/apps/keycloak/conf/ca-certificates'
-    src = '/etc/univention/ssl/ucsCA/CAcert.pem'
-    dst = f'{ca_dir}/my-new-certificate.pem'
-    os.makedirs(os.path.dirname(dst), exist_ok=True)
-    shutil.copyfile(src, dst)
-    run_command(['univention-app', 'configure', 'keycloak'])
-    stdout = run_command(['docker', 'exec', '-u', 'root', 'keycloak', 'keytool', '-cacerts', '-list', '-storepass', 'changeit', '-noprompt'])
-    assert 'my-new-certificate.pem' in stdout, f'certificate not found in {stdout}'
