@@ -201,15 +201,14 @@ def test_login_page_all_elements_are_tabbable(portal_login_via_keycloak, keycloa
     page.keyboard.press("Tab")
     assert page.evaluate("() => document.activeElement.name") == 'password'
     page.keyboard.press("Tab")
-    assert page.evaluate("() => document.activeElement.name") == ''  # switch password
-    page.keyboard.press("Tab")
     assert page.evaluate("() => document.activeElement.name") == 'login'
     # some browser fields
     page.keyboard.press("Tab")
     page.keyboard.press("Tab")
     assert page.evaluate("() => document.activeElement.textContent") == 'English'
-    # and back to the beginning
     page.keyboard.press("Tab")
+    assert page.evaluate("() => document.activeElement.textContent") == 'Deutsch'
+    # and back to the beginning
     assert page.evaluate("() => document.activeElement.name") == 'username'
 
 
