@@ -34,12 +34,8 @@ import subprocess
 from types import SimpleNamespace
 
 import requests
-from bs4 import BeautifulSoup
 from keycloak import KeycloakAdmin
 from playwright.sync_api import Page, expect
-from requests_kerberos import OPTIONAL, HTTPKerberosAuth
-
-from univention.testing.utils import wait_for_listener_replication_and_postrun
 
 
 def host_is_alive(host: str) -> bool:
@@ -54,7 +50,6 @@ def get_portal_tile(page: Page, text: str, portal_config: SimpleNamespace):
 def keycloak_password_change(
     page: Page,
     keycloak_config: SimpleNamespace,
-    username: str,
     password: str,
     new_password: str,
     new_password_confirm: str,
@@ -67,12 +62,7 @@ def keycloak_password_change(
 
     if fails_with:
         error = page.locator(keycloak_config.password_update_error_css_selector.replace("[class='", ".").replace("']", "").replace(" ", "."))
-        assert fails_with in error.inner_text(), f'{fails_with} != {error.inner_text()}'
-        return
-
-    wait_for_listener_replication_and_postrun()
-    if (page.get_by_label("Username or email").is_visible()):
-        keycloak_login(page=page, username=username, password=new_password, keycloak_config=keycloak_config)
+        assert fails_with == error.inner_text(), f'{fails_with} != {error.inner_text()}'
 
 
 def keycloak_auth_header(config: SimpleNamespace) -> dict:
@@ -84,12 +74,6 @@ def keycloak_auth_header(config: SimpleNamespace) -> dict:
     }
 
 
-def keycloak_post_request(config: SimpleNamespace, path: str, params: dict | None = None) -> dict:
-    response = requests.post(f'{config.admin_url}/{path}', headers=keycloak_auth_header(config), params=params)
-    assert response.status_code == 200, response.text
-    return response.json()
-
-
 def keycloak_get_request(config: SimpleNamespace, path: str, params: dict | None = None) -> dict:
     response = requests.get(f'{config.admin_url}/{path}', headers=keycloak_auth_header(config), params=params)
     assert response.status_code == 200, response.text
@@ -147,7 +131,7 @@ def keycloak_login(
 ) -> None:
     name = page.get_by_label("Username or email")
     expect(name, "login form username input not visible").to_be_visible()
-    pw = page.get_by_label("Password", exact=True)
+    pw = page.get_by_label("password")
     expect(pw, "password form input not visible").to_be_visible()
 
     if no_login:
@@ -163,50 +147,6 @@ def run_command(cmd: list) -> str:
     return subprocess.run(cmd, stdout=subprocess.PIPE, check=True).stdout.decode('utf-8')
 
 
-def kerberos_auth(portal_login_via_keycloak, ucr, protocol, portal_config):
-    if protocol == 'oidc':
-        # login with playwright to get rid of the oidc grant
-        # privileges dialog, i don't get it to work with requests
-        #   soup = BeautifulSoup(page.content, features='lxml')
-        #   uri = soup.find('form', {'class': 'form-actions'}).attrs['action']
-        #   code = soup.find('input', {'name': 'code'}).attrs['value']
-        #   data = {'code': code, 'accept': 'Yes'}
-        #   page = session.post(f'https://ucs-sso-ng.ucs.test/{uri}', data=data, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
-        page = portal_login_via_keycloak('Administrator', 'univention', protocol='oidc')
-        portal_logout(page, portal_config)
-        page.close()
-
-    ucr.handler_set(['kerberos/defaults/rdns=false'])
-    subprocess.call(['kdestroy'])
-    subprocess.check_call(['kinit', '--password-file=/var/lib/ucs-test/pwdfile', 'Administrator'])
-    session = requests.Session()
-    session.auth = HTTPKerberosAuth(mutual_authentication=OPTIONAL)
-
-    headers = {'Accept-Language': 'en-US;q=0.6,en;q=0.4', 'Referer': ''}
-    url = f'https://{portal_config.fqdn}/univention/saml/' if protocol == 'saml' else f'https://{portal_config.fqdn}/univention/oidc/'
-    page = session.get(url, data=None, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
-    assert page.status_code == 200
-
-    if protocol == 'saml':
-        soup = BeautifulSoup(page.content, features='lxml')
-        saml_resp = soup.find('input', {'name': 'SAMLResponse'}).attrs['value']
-        relay_state = soup.find('input', {'name': 'RelayState'}).attrs['value']
-        uri = soup.find('form', {'name': 'saml-post-binding'}).attrs['action']
-        print(f'Got URI: {uri}')
-        print(f'Got SAMLResponse: {saml_resp}')
-        print(f'Got RelayState: {relay_state}')
-        assert saml_resp
-        data = {'SAMLResponse': saml_resp, 'RelayState': relay_state}
-        page = session.post(uri, data=data, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
-        assert page.status_code == 200
-
-    cookies = session.cookies.get_dict()
-    assert cookies['UMCUsername'] == 'Administrator'
-    assert 'UMCSessionId' in cookies
-    assert 'AUTH_SESSION_ID' in cookies
-    assert 'KEYCLOAK_IDENTITY' in cookies
-
-
 def legacy_auth_config_remove(session: KeycloakAdmin, groups: dict) -> None:
     """
     groups = {
