@@ -135,8 +135,8 @@ class Interactions:
         logger.info('Found %d modules' % len(modules))
         self.open_modules(modules, limit=limit, start_at=start_at)
 
-    def open_and_close_module(self, module_name: str, wait_for_network_idle: bool = False):
-        self.open_module(_(module_name), wait_for_network_idle=wait_for_network_idle)
+    def open_and_close_module(self, module_name: str):
+        self.open_module(_(module_name))
         # give it a bit more time, e.g. system diagnostic runs longer
         self.page.get_by_role('button', name=_('Close')).click(timeout=60000)
 
@@ -151,13 +151,11 @@ class Interactions:
         self.page.locator('.umcModuleSearchToggleButton').click()
         return result
 
-    def open_module(self, module_name: str, expect_response: re.Pattern[str] | str | None = None, wait_for_network_idle: bool = False):
+    def open_module(self, module_name: str, expect_response: re.Pattern | str | None = None):
         """
         This method opens a module from anywhere where the module search bar in the UCM is visible
 
         :param module_name: the name of the module to be opened
-        :param expect_response: wait for a specific response to be completed before returning
-        :param wait_for_network_idle: wait for no network connections for at least 500ms. Mututally exclusive with expect_response.
         """
         self.page.locator('.umcModuleSearchToggleButton').click()
         logger.info('Clicked the search button')
@@ -167,6 +165,7 @@ class Interactions:
         logger.info('Trying to find button to open module %s' % module_name)
         module_locator = self.page.locator('.umcGalleryName', has_text=exact_module_name)
         expect(module_locator.or_(module_by_title_attrib_locator)).to_be_visible()
+
         if module_by_title_attrib_locator.is_visible():
             clickable_module_locator = module_by_title_attrib_locator
         else:
@@ -177,12 +176,7 @@ class Interactions:
                 clickable_module_locator.click()
         else:
             clickable_module_locator.click()
-
         logger.info('Clicked the module button')
-        if expect_response is None and wait_for_network_idle:
-            logger.info('Waiting for network to be idle...')
-            self.page.wait_for_load_state("networkidle", timeout=30 * 3 * 1000)
-
         if module_name == 'App Center':
             from univention.testing.browser.appcenter import AppCenter, wait_for_final_query
 
@@ -270,12 +264,13 @@ class UMCBrowserTest(Interactions):
     def login(
         self,
         username: str = 'Administrator',
-        password: str = ucr.get('tests/domainadmin/pwd', 'univention'),
+        password: str = 'univention',
         location: str = '/univention/management',
         check_for_no_module_available_popup: bool = False,
         login_should_fail: bool = False,
         do_navigation: bool = True,
         expect_password_change_prompt: bool = False,
+        skip_xhr_check: bool = False,
     ):
         """
         Navigates to {base_url}/univention/login?location={location} and logs in with the given credentials
@@ -287,6 +282,7 @@ class UMCBrowserTest(Interactions):
         :param login_should_fail: Returns after failure to log in with wrong credentials
         :param do_navigation: Wether to navigate to the login page
         :param expect_password_change_prompt: Expect a password change prompt to be visible after clicking the Login button
+        :param skip_xhr_check: Skip the check for certain requests to be completed
         """
         logger.info("Starting login to '%s' " % location)
         page = self.page
@@ -311,7 +307,18 @@ class UMCBrowserTest(Interactions):
             logger.info('Login failed as expected')
             return
 
-        if check_for_no_module_available_popup:
+        if '/univention/management' in location and not check_for_no_module_available_popup and not skip_xhr_check:
+            logger.info('Logging in, waiting for requests to finish')
+            join_script_query = re.compile(r'https?://.+/univention/command/join/scripts/query')
+            license_query = re.compile(r'https?://.+/univention/command/udm/license')
+
+            if ucr.get('server/role') == 'domaincontroller_master':
+                with self.page.expect_response(join_script_query), self.page.expect_response(license_query):
+                    login_button.click()
+            else:
+                with self.page.expect_response(join_script_query):
+                    login_button.click()
+        elif check_for_no_module_available_popup:
             login_button.click()
             logger.info("Checking for the 'No module for user available popup'")
             self.check_for_no_module_available_popup()
