@@ -35,11 +35,10 @@
 import re
 import subprocess
 import time
+from typing import Literal
 
 from playwright.sync_api import Page, expect
-from typing_extensions import Literal
 
-from univention.config_registry import ucr
 from univention.lib.i18n import Translation
 from univention.testing.browser.lib import UMCBrowserTest
 
@@ -56,7 +55,7 @@ class ProcessOverview:
         self.module_name = _('Process overview')
         self.grid_load_url = re.compile('.*univention/command/top/query.*')
 
-    def navigate(self, username=ucr.get('tests/domainadmin/username', 'Administrator'), password=ucr.get('tests/domainadmin/pwd', 'univention')):
+    def navigate(self, username='Administrator', password='univention'):
         self.tester.login(username, password)
         self.tester.open_module(self.module_name, self.grid_load_url)
 
