@@ -33,7 +33,6 @@
 import os
 import time
 from pathlib import Path
-from typing import Union
 from urllib.parse import quote
 
 from playwright.sync_api import BrowserContext, Page, expect
@@ -61,17 +60,17 @@ def check_for_backtrace(page: Page, page_index: int = 0):
         pass
 
 
-def print_path_in_jenkins(name: str, ucr, typ='screenshot'):
+def print_path_in_jenkins(name: str, ucr):
     subfolder = ''
     if os.environ.get('JENKINS_WS'):
         if 'master' not in ucr.get('server/role'):
             subfolder = f"{ucr.get('hostname')}/"
         full_url = f"{os.environ['JENKINS_WS']}ws/test/{quote(subfolder)}browser/{quote(name)}"
-        logger.info('Browser %s URL: %s' % (typ, full_url))
+        logger.info('Browser screenshot URL: %s' % full_url)
 
 
-def save_screenshot(page: Page, node_name, path: Path, ucr, page_index: int = 0, timestamp: Union[int, None] = None):
-    ts = timestamp or time.time_ns()
+def save_screenshot(page: Page, node_name, path: Path, ucr, page_index: int = 0):
+    ts = time.time_ns()
 
     screenshot_filename = path / f'{ts}-{node_name}-page_{page_index}.jpeg'
 
@@ -86,9 +85,8 @@ def save_trace(
     path: Path,
     ucr,
     tracing_stop_chunk: bool = False,
-    timestamp: Union[int, None] = None
 ):
-    ts = timestamp or time.time_ns()
+    ts = time.time_ns()
 
     trace_filename = path / f'{ts}-{node_name}_trace.zip'
 
@@ -97,4 +95,4 @@ def save_trace(
     else:
         context.tracing.stop(path=trace_filename)
 
-    print_path_in_jenkins(trace_filename.name, ucr, 'trace')
+    print_path_in_jenkins(trace_filename.name, ucr)
