@@ -31,7 +31,6 @@
 # <https://www.gnu.org/licenses/>.
 
 import subprocess
-import time
 from pathlib import Path
 from typing import Dict, Generator, Iterator, List, Union
 
@@ -236,11 +235,10 @@ def teardown_umc_browser_test(
         page = [page]
     try:
         if 'call' in report and report['call'].failed:
-            failure_timestamp = time.time_ns()
 
-            save_trace(context, request.node.name, Path('browser').resolve(), ucr, timestamp=failure_timestamp)
+            save_trace(context, request.node.name, Path('browser').resolve(), ucr)
             for i, p in enumerate(page):
-                save_screenshot(p, request.node.name, Path('browser'), ucr, i, timestamp=failure_timestamp)
+                save_screenshot(p, request.node.name, Path('browser'), ucr, i)
                 check_for_backtrace(p, page_index=i)
         else:
             context.tracing.stop()
