@@ -32,9 +32,7 @@
 
 from __future__ import annotations
 
-import contextlib
 import functools
-import logging
 import os
 import socket
 import subprocess
@@ -44,7 +42,7 @@ import traceback
 from enum import IntEnum
 from itertools import chain
 from types import TracebackType
-from typing import IO, Any, Callable, Dict, Iterable, List, Mapping, NoReturn, Sequence, Text, Tuple, Type, TypeVar
+from typing import IO, Any, Callable, Dict, Iterable, List, Mapping, NoReturn, Sequence, Tuple, Type, TypeVar
 
 import ldap
 
@@ -52,8 +50,6 @@ from univention import uldap
 from univention.config_registry import ConfigRegistry
 
 
-logger = logging.getLogger('test')
-
 try:
     from univention.admin.uldap import access
 except ImportError:
@@ -120,7 +116,7 @@ class UCSTestDomainAdminCredentials:
         else:
             self.bindpw = ucr.get('tests/domainadmin/pwd', 'univention')
         if self.binddn:
-            self.username: Text | None = uldap.explodeDn(self.binddn, 1)[0]
+            self.username: str | None = uldap.explodeDn(self.binddn, 1)[0]
         else:
             self.username = None
 
@@ -144,7 +140,7 @@ def get_ldap_connection(admin_uldap: bool = False, primary: bool = False) -> acc
 
     for ldap_server in ldap_servers:
         try:
-            lo = uldap.access(host=ldap_server, port=port, base=ucr['ldap/base'], binddn=creds.binddn, bindpw=creds.bindpw, start_tls=2, decode_ignorelist=[], follow_referral=True)
+            lo = uldap.access(host=ldap_server, port=port, base=ucr['ldap/base'], binddn=creds.binddn, bindpw=creds.bindpw, start_tls=2, follow_referral=True)
             if admin_uldap:
                 lo = access(lo=lo)
             return lo
@@ -356,27 +352,6 @@ def restart_listener() -> None:
     subprocess.call(('systemctl', 'restart', 'univention-directory-listener'))
 
 
-def stop_adconnector() -> None:
-    subprocess.check_call(['systemctl', 'stop', 'univention-ad-connector'])
-
-
-def start_adconnector() -> None:
-    subprocess.check_call(['systemctl', 'start', 'univention-ad-connector'])
-
-
-def restart_adconnector() -> None:
-    subprocess.check_call(['systemctl', 'restart', 'univention-ad-connector'])
-
-
-@contextlib.contextmanager
-def adconnector_stopped():
-    try:
-        stop_adconnector()
-        yield
-    finally:
-        start_adconnector()
-
-
 def restart_firewall() -> None:
     subprocess.call((FIREWALL_INIT_SCRIPT, 'restart'))
 
@@ -590,11 +565,10 @@ def wait_for_listener_replication_and_postrun(verbose: bool = True) -> None:
             seconds_since_last_change += 1
         else:
             seconds_since_last_change = 0
-
-        # Less than 15 sec because a postrun function can potentially make ldap changes,
-        # which would result in a loop here.
         if seconds_since_last_change > 12:
-            time.sleep(20)  # Give the postrun function some time
+            # Less than 15 sec because a postrun function can potentially make ldap changes,
+            # which would result in a loop here.
+            time.sleep(10)  # Give the postrun function some time
             if verbose:
                 print("Postrun should have run")
             return
@@ -684,31 +658,6 @@ def is_port_open(port: int, hosts: Iterable[str] | None = None, timeout: float =
     return False
 
 
-def no_change_in_file(no_change_for: int, log_file: str) -> bool:
-    modify_time = os.path.getmtime(log_file)
-    current_time = time.time()
-    if (current_time - modify_time) >= no_change_for:
-        return True
-    return False
-
-
-def wait_for_s4_connector_to_be_inactive(no_change_for: int = 10) -> None:
-    log_file = '/var/log/univention/connector-s4.log'
-    if not os.path.isfile(log_file):
-        return
-    for i in range(30):
-        if no_change_in_file(no_change_for, log_file):
-            logger.debug(f'no change in {log_file} for {no_change_for}s')
-            print(f'no change in {log_file} for {no_change_for}s')
-            break
-        logger.info('connector is active, waiting')
-        print('connector is active, waiting')
-        time.sleep(no_change_for + 3)
-    else:
-        print('wait_for_s4_connector_to_be_inactive timed out, contiuing anyway')
-        logger.error('wait_for_s4_connector_to_be_inactive timed out, contiuing anyway')
-
-
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
